import { Injectable } from "@angular/core";
import { LocationPickerConfigsModel } from "../models/location-picker-configs.model";
import { GoogleLocationApiService } from "@justbe-angular/jb-google-location-api";
import { Observable } from "rxjs";
import { Platform, App } from "ionic-angular";
import { Geolocation } from '@ionic-native/geolocation';
import { LocationPickerPage } from "../pages/location-picker/location-picker.page";
var LocationPickerService = (function () {
    function LocationPickerService(jbGoogleApi, plt, googleLocationApiService, geolocation, app) {
        this.jbGoogleApi = jbGoogleApi;
        this.plt = plt;
        this.googleLocationApiService = googleLocationApiService;
        this.geolocation = geolocation;
        this.app = app;
    }
    ;
    LocationPickerService.prototype.setConfigurations = function (obj) {
        this.configs = LocationPickerConfigsModel.build(obj);
        this.jbGoogleApi.setConfigurations(obj.googleLocationApiConfigs);
    };
    LocationPickerService.prototype.getMyLocation = function () {
        var _this = this;
        return new Observable(function (observer) {
            var that = _this;
            var outputObj = {};
            if (_this.plt.is('core') || _this.plt.is('mobileweb')) {
                if (navigator.geolocation) {
                    navigator.geolocation.getCurrentPosition(function (position) {
                        outputObj.lat = position.coords.latitude;
                        outputObj.lng = position.coords.longitude;
                        that.setNearbyLocations(outputObj, observer);
                    }, function error(msg) {
                        observer.error(msg);
                    });
                }
            }
            else {
                _this.geolocation.getCurrentPosition().then(function (resp) {
                    outputObj.lat = resp.coords.latitude;
                    outputObj.lng = resp.coords.longitude;
                    that.setNearbyLocations(outputObj, observer);
                }).catch(function (error) {
                    observer.error(error);
                });
            }
        });
    };
    LocationPickerService.prototype.setNearbyLocations = function (outputObj, observer) {
        this.googleLocationApiService.reverseGeocode(outputObj.lat, outputObj.lng).subscribe(function (res) {
            if (res.status === 'OK') {
                outputObj.results = res.results;
                observer.next(outputObj);
                observer.complete();
            }
            else {
                observer.error('no locations found');
            }
        });
    };
    LocationPickerService.prototype.openLocationPicker = function () {
        this.app.getActiveNav().push(LocationPickerPage);
    };
    LocationPickerService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    LocationPickerService.ctorParameters = function () { return [
        { type: GoogleLocationApiService, },
        { type: Platform, },
        { type: GoogleLocationApiService, },
        { type: Geolocation, },
        { type: App, },
    ]; };
    return LocationPickerService;
}());
export { LocationPickerService };
//# sourceMappingURL=location-picker.service.js.map